# coding: utf-8

"""
    Fabric Credential Manager API

    This is Fabric Credential Manager API  # noqa: E501

    OpenAPI spec version: 1.0.2
    Contact: kthare10@unc.edu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.models.revoke_list import RevokeList  # noqa: E501
from swagger_client.rest import ApiException


class TestRevokeList(unittest.TestCase):
    """RevokeList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRevokeList(self):
        """Test RevokeList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.revoke_list.RevokeList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
