# coding: utf-8

"""
    Fabric Credential Manager API

    This is Fabric Credential Manager API  # noqa: E501

    OpenAPI spec version: 1.0.2
    Contact: kthare10@unc.edu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

from fabric_cm.credmgr.swagger_client.api.default_api import DefaultApi  # noqa: E501
from fabric_cm.credmgr.swagger_client.rest import ApiException


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_certs_get(self):
        """Test case for certs_get

        Return Public Keys to verify signature of the tokens  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
